@@ -33,8 +33,6 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
-
             bpl.default_style()
 
             fig, (ax0, ax1) = bpl.subplots(figsize=[12, 5], ncols=2)
@@ -79,8 +77,6 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
-
             bpl.default_style()
 
             fig, (ax0, ax1) = bpl.subplots(ncols=2, figsize=[10, 5])
@@ -149,8 +145,6 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
-
             bpl.default_style()
 
             fig, (ax0, ax1) = bpl.subplots(ncols=2, figsize=[10, 5])
@@ -205,20 +199,25 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
+            import matplotlib.pyplot as plt
             import numpy as np
-
             bpl.default_style()
 
-            x1 = np.random.normal(0, scale=0.5, size=500)
-            y1 = np.random.normal(0, scale=0.5, size=500)
-            x2 = np.random.normal(0.5, scale=0.5, size=500)
-            y2 = np.random.normal(0.5, scale=0.5, size=500)
-            x3 = np.random.normal(1, scale=0.5, size=500)
-            y3 = np.random.normal(1, scale=0.5, size=500)
+            x = np.random.normal(0, scale=0.5, size=500)
+            y = np.random.normal(0, scale=0.5, size=500)
+            
+            fig = plt.figure(figsize=[15, 7])
+            ax1 = fig.add_subplot(121)
+            ax2 = fig.add_subplot(122, projection="bpl")
+            
+            for ax in [ax1, ax2]:
+                ax.scatter(x,     y)
+                ax.scatter(x+0.5, y+0.5)
+                ax.scatter(x+1,   y+1)
+            
+            ax1.set_title("matplotlib")
+            ax2.add_labels(title="betterplotlib")
 
-            bpl.scatter(x1, y1)
-            bpl.scatter(x2, y2)
-            bpl.scatter(x3, y3)
         """
 
         # get the color, if it hasn't already been set. I don't need to do this
@@ -319,7 +318,15 @@ class Axes_bpl(Axes):
 
             data = np.random.normal(0, 2, 10000)
 
-            bpl.hist(data)
+            fig = plt.figure(figsize=[15, 7])
+            ax1 = fig.add_subplot(121)
+            ax2 = fig.add_subplot(122, projection="bpl")
+            
+            ax1.hist(data)
+            ax2.hist(data)
+            
+            ax1.set_title("matplotlib")
+            ax2.add_labels(title="betterplotlib")
 
         There are also plenty of options that make other histograms look nice 
         too.
@@ -328,9 +335,7 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
-
             bpl.default_style()
 
             data1 = np.random.normal(-6, 1, size=10000)
@@ -411,15 +416,13 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
-
             bpl.default_style()
 
             xs = np.arange(0, 10, 0.1)
             ys = xs**2
 
-            plt.plot(xs, ys)
+            bpl.plot(xs, ys)
             bpl.add_labels("X value", "Y value", "Title")
         """
         if x_label is not None:
@@ -455,9 +458,7 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
-
             bpl.default_style()
 
             xs = np.arange(0, 10, 0.01)
@@ -513,9 +514,7 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
-
             bpl.default_style()
 
             xs = np.arange(0, 7, 0.1)
@@ -571,9 +570,7 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
-
             bpl.default_style()
 
             xs = np.arange(0, 5, 0.1)
@@ -611,26 +608,31 @@ class Axes_bpl(Axes):
                        ax.legend() function. This will be things like loc, 
                        and title, etc.
         :return: legend object returned by the ax.legend() function.
-
+        
         The default legend is a transparent background with no border, like so.
 
         .. plot::
             :include-source:
 
+            import numpy as np
             import betterplotlib as bpl
             import matplotlib.pyplot as plt
-            import numpy as np
-
             bpl.default_style()
 
             x = np.arange(0, 5, 0.1)
 
-            fig, ax = bpl.subplots()
-
-            ax.plot(x, x, label="x")
-            ax.plot(x, 2*x, label="2x")
-            ax.plot(x, 3*x, label="3x")
-            ax.legend()
+            fig = plt.figure(figsize=[15, 7])
+            ax1 = fig.add_subplot(121)
+            ax2 = fig.add_subplot(122, projection="bpl")  # bpl subplot.
+            
+            for ax in [ax1, ax2]:
+                ax.plot(x, x, label="x")
+                ax.plot(x, 2*x, label="2x")
+                ax.plot(x, 3*x, label="3x")
+                ax.legend(loc=2)
+            
+            ax1.set_title("matplotlib")
+            ax2.set_title("betterplotlib")
 
         You can still pass in any kwargs to the legend function you want.
 
@@ -638,7 +640,6 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
 
             bpl.default_style()
@@ -695,7 +696,6 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
 
             bpl.default_style()
@@ -721,7 +721,6 @@ class Axes_bpl(Axes):
             :include-source:
 
             import betterplotlib as bpl
-            import matplotlib.pyplot as plt
             import numpy as np
 
             bpl.default_style()
@@ -784,9 +783,7 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import betterplotlib as bpl
-
             bpl.default_style()
 
             bpl.easy_add_text("1", 1)
@@ -802,9 +799,7 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import betterplotlib as bpl
-
             bpl.default_style()
 
             bpl.easy_add_text("upper left", "upper left")
@@ -974,10 +969,8 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import numpy as np
             import betterplotlib as bpl
-
             bpl.default_style()
 
             xs = np.concatenate([np.random.normal(0, 1, 100000),
@@ -1000,10 +993,8 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import numpy as np
             import betterplotlib as bpl
-
             bpl.default_style()
 
             xs = np.concatenate([np.random.normal(0, 1, 100000),
@@ -1029,10 +1020,8 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import numpy as np
             import betterplotlib as bpl
-
             bpl.default_style()
 
             xs = np.concatenate([np.random.normal(0, 1, 100000),
@@ -1055,10 +1044,8 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import numpy as np
             import betterplotlib as bpl
-
             bpl.default_style()
 
             xs = np.concatenate([np.random.normal(0, 1, 100000),
@@ -1083,10 +1070,8 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import numpy as np
             import betterplotlib as bpl
-
             bpl.default_style()
 
             xs = np.concatenate([np.random.normal(0, 1, 100000),
@@ -1134,10 +1119,8 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import numpy as np
             import betterplotlib as bpl
-
             bpl.default_style()
 
             rad1 = np.random.normal(10, 0.75, 100000)
@@ -1274,7 +1257,6 @@ class Axes_bpl(Axes):
         .. plot::
             :include-source:
 
-            import matplotlib.pyplot as plt
             import numpy as np
             import betterplotlib as bpl
             bpl.default_style()
@@ -1317,15 +1299,25 @@ class Axes_bpl(Axes):
 
             import numpy as np
             import betterplotlib as bpl
+            import matplotlib.pyplot as plt
             bpl.default_style()
 
             xs = np.arange(0, 1, 0.01)
             ys_1 = xs
             ys_2 = xs**2
 
-            fig, ax = bpl.subplots()
-            ax.plot(xs, ys_1) 
-            ax.plot(xs, ys_2) 
+            fig = plt.figure(figsize=[15, 7])
+            ax1 = fig.add_subplot(121)
+            ax2 = fig.add_subplot(122, projection="bpl")  # bpl subplot.
+            
+            ax1.plot(xs, ys_1) 
+            ax1.plot(xs, ys_2) 
+            
+            ax2.plot(xs, ys_1) 
+            ax2.plot(xs, ys_2) 
+            
+            ax1.set_title("matplotlib")
+            ax2.set_title("betterplotlib")
 
         """
         # set the linewidth to a thicker value. There are two keys here, though,
@@ -1422,7 +1414,33 @@ class Axes_bpl(Axes):
         automatically a scatter plot, rather than the connected lines that
         are used by default otherwise. It also adds a black marker edge to
         distinguish the markers when there are lots of data poitns. Otherwise
-        everything blends together. """
+        everything blends together.
+        
+        .. plot::
+            :include-source:
+
+            import numpy as np
+            import betterplotlib as bpl
+            import matplotlib.pyplot as plt
+            bpl.default_style()
+            
+            xs = np.random.normal(0, 1, 100)
+            ys = np.random.normal(0, 1, 100)
+            yerr = np.random.uniform(0.3, 0.8, 100)
+            xerr = np.random.uniform(0.3, 0.8, 100)
+            
+            fig = plt.figure(figsize=[15, 7])
+            ax1 = fig.add_subplot(121)
+            ax2 = fig.add_subplot(122, projection="bpl")  # bpl subplot.
+            
+            for ax in [ax1, ax2]:
+                ax.errorbar(xs,   ys,   xerr=xerr, yerr=yerr, label="set 1")
+                ax.errorbar(xs+1, ys+1, xerr=xerr, yerr=yerr, label="set 2")
+                ax.legend()
+            ax1.set_title("matplotlib")
+            ax2.set_title("betterplotlib")
+            
+            """
 
         kwargs.setdefault("capsize", 0)
         kwargs.setdefault("fmt", "o")
@@ -1431,5 +1449,63 @@ class Axes_bpl(Axes):
 
         return super(Axes_bpl, self).errorbar(*args, **kwargs)
 
+    def simple_twin_axis(self, axis, lower_lim, upper_lim, label="", log=False):
+        """Creates a differently scaled axis on either the top or the left.
+    
+        This can be used to put multiple scales on one plot for easier 
+        comparison. Some examples might be distance/time, redshift/age, or
+        any two related quantities.
+        
+        Note that this only does simple scalings of the new axes, which will 
+        still only be linear or log scaled axes. If you want a function that
+        smartly places labels based on a function that takes one set of axes
+        values to another (in a potentially nonlinear way), the other function 
+        I haven't made will do that. 
+    
+        :param axis: Where the new scaled axis will be placed. Must
+                     either be "x" or "y". 
+        :param lower_lim: Value to be put on the left/bottom of the newly
+                          created axis.
+        :param upper_lim: Value to be put on the right/top of the newly 
+                          created axis. 
+        :param label: The label to put on this new axis. 
+        :param log: Whether or not to log scale this axis.
+        :returns: the new axes
+        
+        .. plot::
+            :include-source:
+            
+            import betterplotlib as bpl
+            bpl.presentation_style()
+            
+            fig, ax = bpl.subplots(figsize=[5, 5])
+            ax.set_limits(0, 10, 0, 5)
+            ax.add_labels("x", "y")
+            ax.simple_twin_axis("x", 0, 100, r"$10 x$")
+            ax.simple_twin_axis("y", 1, 10**5, r"$10^y$", log=True)
+            
+        Note that for a slightly more complicated version of this plot, say if
+        we wanted the top x axis to be x^2 rather than 10x, the limits would
+        still be the same, but since the new axis will always be a linear or log
+        scale the new axis won't represent the true relationship between the
+        variables on the twin axes. See the other function for that. 
+            
+            
+        """
 
+        if axis == "x":
+            new_ax = super(Axes_bpl, self).twiny()
+            new_ax.set_xlim(lower_lim, upper_lim)
+            if log:
+                new_ax.set_xscale("log")
+            new_ax.set_xlabel(label)
+        elif axis == "y":
+            new_ax = super(Axes_bpl, self).twinx()
+            new_ax.set_ylim(lower_lim, upper_lim)
+            if log:
+                new_ax.set_yscale("log")
+            new_ax.set_ylabel(label)
+        else:
+            raise ValueError("Axis must be either 'x' or 'y'. ")
 
+        return new_ax
